/* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
/*
 * SPDX-License-Identifier: MIT OR LGPL-2.0-or-later
 * SPDX-FileCopyrightText: 2008 litl, LLC
 */

#ifndef GJS_GJS_H_
#define GJS_GJS_H_

#define INSIDE_GJS_H

#include <gjs/context.h>
#include <gjs/coverage.h>
#include <gjs/error-types.h>
#include <gjs/macros.h>
#include <gjs/mem.h>
#include <gjs/profiler.h>

#undef INSIDE_GJS_H

#endif /* GJS_GJS_H_ */
